@@ -25,6 +25,8 @@ Eigen::VectorXd pc;
 Eigen::MatrixXd delta0;
 double I;
 
+// Rcout << Ineq;
+
 // for output
 NumericVector out(3);
 
@@ -41,9 +43,10 @@ for (int i = 0; i < s; i++) {
     theta = thetaTMP.transpose();
 	
 	// added check to avoid multiplication with Ineq if only of size (1,1) (i.e., no inequality restrictions)
-	if (Ineq.rows() == 1 && Ineq.rows() == 1 && Ineq(0,0) == 0)  {
+	if (Ineq.rows() == 1 && Ineq.cols() == 1 && Ineq(0,0) == 0)  {
 		IneqT.resize(1);
 		IneqT(0) = 0;
+		//Rcout << "\nno inequalities";
 	} else
 		IneqT = (theta*Ineq.transpose());
   
